﻿/*
Copyright (c) 2003-2022, CKSource Holding sp. z o.o. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'colorbutton', 'he', {
	auto: 'אוטומטי',
	bgColorTitle: 'צבע רקע',
	colors: {
		'000': 'שחור',
		'800000': 'סגול כהה',
		'8B4513': 'חום בהיר',
		'2F4F4F': 'אפור צפחה',
		'008080': 'כחול-ירוק',
		'000080': 'כחול-סגול',
		'4B0082': 'אינדיגו',
		'696969': 'אפור מעומעם',
		B22222: 'אדום-חום',
		A52A2A: 'חום',
		DAA520: 'כתום זהב',
		'006400': 'ירוק כהה',
		'40E0D0': 'טורקיז',
		'0000CD': 'כחול בינוני',
		'800080': 'סגול',
		'808080': 'אפור',
		F00: 'אדום',
		FF8C00: 'כתום כהה',
		FFD700: 'זהב',
		'008000': 'ירוק',
		'0FF': 'ציאן',
		'00F': 'כחול',
		EE82EE: 'סגלגל',
		A9A9A9: 'אפור כהה',
		FFA07A: 'כתום-וורוד',
		FFA500: 'כתום',
		FFFF00: 'צהוב',
		'00FF00': 'ליים',
		AFEEEE: 'טורקיז בהיר',
		ADD8E6: 'כחול בהיר',
		DDA0DD: 'שזיף',
		D3D3D3: 'אפור בהיר',
		FFF0F5: 'לבנדר מסמיק',
		FAEBD7: 'לבן עתיק',
		FFFFE0: 'צהוב בהיר',
		F0FFF0: 'טל דבש',
		F0FFFF: 'תכלת',
		F0F8FF: 'כחול טיפת מים',
		E6E6FA: 'לבנדר',
		FFF: 'לבן',
		'1ABC9C': 'Strong Cyan', // MISSING
		'2ECC71': 'Emerald', // MISSING
		'3498DB': 'Bright Blue', // MISSING
		'9B59B6': 'Amethyst', // MISSING
		'4E5F70': 'Grayish Blue', // MISSING
		'F1C40F': 'Vivid Yellow', // MISSING
		'16A085': 'Dark Cyan', // MISSING
		'27AE60': 'Dark Emerald', // MISSING
		'2980B9': 'Strong Blue', // MISSING
		'8E44AD': 'Dark Violet', // MISSING
		'2C3E50': 'Desaturated Blue', // MISSING
		'F39C12': 'Orange', // MISSING
		'E67E22': 'Carrot', // MISSING
		'E74C3C': 'Pale Red', // MISSING
		'ECF0F1': 'Bright Silver', // MISSING
		'95A5A6': 'Light Grayish Cyan', // MISSING
		'DDD': 'Light Gray', // MISSING
		'D35400': 'Pumpkin', // MISSING
		'C0392B': 'Strong Red', // MISSING
		'BDC3C7': 'Silver', // MISSING
		'7F8C8D': 'Grayish Cyan', // MISSING
		'999': 'Dark Gray' // MISSING
	},
	more: 'צבעים נוספים...',
	panelTitle: 'צבעים',
	textColorTitle: 'צבע טקסט'
} );
